pub struct Task<F, H, M> { /* private fields */ }Trait Implementations
Sourceimpl<State, Action, F, H, M, Fut> View<State, Action, ViewCtx> for Task<F, H, M>where
State: 'static,
Action: 'static,
F: Fn(TaskProxy, ShutdownSignal) -> Fut + 'static,
Fut: Future<Output = ()> + 'static,
H: Fn(&mut State, M) -> Action + 'static,
M: AnyDebug,
impl<State, Action, F, H, M, Fut> View<State, Action, ViewCtx> for Task<F, H, M>where
State: 'static,
Action: 'static,
F: Fn(TaskProxy, ShutdownSignal) -> Fut + 'static,
Fut: Future<Output = ()> + 'static,
H: Fn(&mut State, M) -> Action + 'static,
M: AnyDebug,
Sourcetype ViewState = TaskState
type ViewState = TaskState
State that is used over the lifetime of the retained representation of the view. Read more
Sourcefn build(
&self,
ctx: &mut ViewCtx,
_: &mut State,
) -> (Self::Element, Self::ViewState)
fn build( &self, ctx: &mut ViewCtx, _: &mut State, ) -> (Self::Element, Self::ViewState)
Create the corresponding Element value.
Sourcefn rebuild(
&self,
_: &Self,
_: &mut Self::ViewState,
_: &mut ViewCtx,
(): Mut<'_, Self::Element>,
_: &mut State,
)
fn rebuild( &self, _: &Self, _: &mut Self::ViewState, _: &mut ViewCtx, (): Mut<'_, Self::Element>, _: &mut State, )
Update
element based on the difference between self and prev.Sourcefn teardown(
&self,
view_state: &mut Self::ViewState,
_: &mut ViewCtx,
_: Mut<'_, Self::Element>,
)
fn teardown( &self, view_state: &mut Self::ViewState, _: &mut ViewCtx, _: Mut<'_, Self::Element>, )
Handle
element being removed from the tree. Read moreSourcefn message(
&self,
_: &mut Self::ViewState,
message: &mut MessageContext,
_element: Mut<'_, Self::Element>,
app_state: &mut State,
) -> MessageResult<Action>
fn message( &self, _: &mut Self::ViewState, message: &mut MessageContext, _element: Mut<'_, Self::Element>, app_state: &mut State, ) -> MessageResult<Action>
Route
message to id_path, if that is still a valid path.impl<F, H, M> ViewMarker for Task<F, H, M>