pub struct Audio<Children, State, Action> { /* private fields */ }Trait Implementations
Sourceimpl<Children, State, Action> View<State, Action, ViewCtx> for Audio<Children, State, Action>where
Children: 'static,
State: 'static,
Action: 'static,
impl<Children, State, Action> View<State, Action, ViewCtx> for Audio<Children, State, Action>where
Children: 'static,
State: 'static,
Action: 'static,
Sourcetype Element = Pod<HtmlAudioElement>
type Element = Pod<HtmlAudioElement>
The element type which this view operates on.
Sourcetype ViewState = ElementState
type ViewState = ElementState
State that is used over the lifetime of the retained representation of the view. Read more
Sourcefn build(
&self,
ctx: &mut ViewCtx,
app_state: &mut State,
) -> (Self::Element, Self::ViewState)
fn build( &self, ctx: &mut ViewCtx, app_state: &mut State, ) -> (Self::Element, Self::ViewState)
Create the corresponding Element value.
Sourcefn rebuild(
&self,
prev: &Self,
element_state: &mut Self::ViewState,
ctx: &mut ViewCtx,
element: Mut<'_, Self::Element>,
app_state: &mut State,
)
fn rebuild( &self, prev: &Self, element_state: &mut Self::ViewState, ctx: &mut ViewCtx, element: Mut<'_, Self::Element>, app_state: &mut State, )
Update
element based on the difference between self and prev.Sourcefn teardown(
&self,
element_state: &mut Self::ViewState,
ctx: &mut ViewCtx,
element: Mut<'_, Self::Element>,
)
fn teardown( &self, element_state: &mut Self::ViewState, ctx: &mut ViewCtx, element: Mut<'_, Self::Element>, )
Handle
element being removed from the tree. Read moreSourcefn message(
&self,
element_state: &mut Self::ViewState,
message: &mut MessageContext,
element: Mut<'_, Self::Element>,
app_state: &mut State,
) -> MessageResult<Action>
fn message( &self, element_state: &mut Self::ViewState, message: &mut MessageContext, element: Mut<'_, Self::Element>, app_state: &mut State, ) -> MessageResult<Action>
Route
message to id_path, if that is still a valid path.impl<Children, State, Action> ViewMarker for Audio<Children, State, Action>