pub struct OnTimeUpdate<V, State, Action, Callback> { /* private fields */ }Implementations
Sourceimpl<V, State, Action, Callback> OnTimeUpdate<V, State, Action, Callback>
impl<V, State, Action, Callback> OnTimeUpdate<V, State, Action, Callback>
pub fn new(dom_view: V, handler: Callback) -> Self
Sourcepub fn passive(self, value: bool) -> Self
pub fn passive(self, value: bool) -> Self
Whether the event handler should be passive. (default = true)
Passive event handlers can’t prevent the browser’s default action from
running (otherwise possible with event.prevent_default()), which
restricts what they can be used for, but reduces overhead.
Sourcepub fn capture(self, value: bool) -> Self
pub fn capture(self, value: bool) -> Self
Whether the event handler should capture the event before being dispatched to any EventTarget beneath it in the DOM tree. (default = false)
Events that are bubbling upward through the tree will not trigger a listener designated to use capture. Event bubbling and capturing are two ways of propagating events that occur in an element that is nested within another element, when both elements have registered a handle for that event. The event propagation mode determines the order in which elements receive the event.